pub struct Fmc<'d, T: Instance> { /* private fields */ }Expand description
FMC driver
Implementations
Sourceimpl<'d, T> Fmc<'d, T>where
T: Instance,
impl<'d, T> Fmc<'d, T>where
T: Instance,
Sourcepub fn new_raw(_instance: Peri<'d, T>) -> Self
pub fn new_raw(_instance: Peri<'d, T>) -> Self
Create a raw FMC instance.
Note: This is currently used to provide access to some basic FMC functions for manual configuration for memory types that stm32-fmc does not support.
Sourcepub fn memory_controller_enable(&mut self)
pub fn memory_controller_enable(&mut self)
Enable the memory controller on applicable chips.
Sourcepub fn source_clock_hz(&self) -> u32
pub fn source_clock_hz(&self) -> u32
Get the kernel clock currently in use for this FMC instance.